@@ -883,27 +883,6 @@ podcast_post_status_sort_func (RhythmDBEntry *a,
 	return ret;
 }
 
-
-static void
-episode_activated_cb (RBEntryView *view,
-		      RhythmDBEntry *entry,
-		      RBPodcastSource *source)
-{
-	GValue val = {0,};
-
-	/* check to see if it has already been downloaded */
-	if (rb_podcast_manager_entry_downloaded (entry))
-		return;
-
-	g_value_init (&val, G_TYPE_ULONG);
-	g_value_set_ulong (&val, RHYTHMDB_PODCAST_STATUS_WAITING);
-	rhythmdb_entry_set (source->priv->db, entry, RHYTHMDB_PROP_STATUS, &val);
-	rhythmdb_commit (source->priv->db);
-	g_value_unset (&val);
-
-	rb_podcast_manager_download_entry (source->priv->podcast_mgr, entry);
-}
-
 static void
 podcast_entry_changed_cb (RhythmDB *db,
 			  RhythmDBEntry *entry,
@@ -1365,6 +1344,8 @@ impl_constructed (GObject *object)
 	builder = rb_builder_load ("podcast-popups.ui", NULL);
 	source->priv->feed_popup = G_MENU_MODEL (gtk_builder_get_object (builder, "podcast-feed-popup"));
 	source->priv->episode_popup = G_MENU_MODEL (gtk_builder_get_object (builder, "podcast-episode-popup"));
+	g_object_ref (source->priv->feed_popup);
+	g_object_ref (source->priv->episode_popup);
 	g_object_unref (builder);
 
 	source->priv->default_search = rb_source_search_basic_new (RHYTHMDB_PROP_SEARCH_MATCH, NULL);
@@ -1378,11 +1359,6 @@ impl_constructed (GObject *object)
 						 TRUE, FALSE);
 	g_object_unref (shell_player);
 
-	g_signal_connect_object (source->priv->posts,
-				 "entry-activated",
-				 G_CALLBACK (episode_activated_cb),
-				 source, 0);
-
 	/* Podcast date column */
 	column = gtk_tree_view_column_new ();
 	renderer = gtk_cell_renderer_text_new();
@@ -1483,6 +1459,7 @@ impl_constructed (GObject *object)
 	source->priv->feeds = rb_property_view_new (source->priv->db,
 						    RHYTHMDB_PROP_SUBTITLE,
 						    _("Feed"));
+	rb_property_view_set_column_visible (RB_PROPERTY_VIEW (source->priv->feeds), FALSE);
 	rb_property_view_set_selection_mode (RB_PROPERTY_VIEW (source->priv->feeds),
 					     GTK_SELECTION_MULTIPLE);
 
